Struct InvitePermissionConfigEventContent
#[non_exhaustive]pub struct InvitePermissionConfigEventContent {
pub default_action: Option<InvitePermissionAction>,
}Expand description
The content of an m.invite_permission_config account data.
Controls whether invites to this account are permitted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_action: Option<InvitePermissionAction>The default action chosen by the user that the homeserver should perform automatically when receiving an invitation for this account.
A missing, invalid or unsupported value means that the user wants to receive invites as normal. Other parts of the specification might still have effects on invites, like ignoring users.
Implementations
impl InvitePermissionConfigEventContent
impl InvitePermissionConfigEventContent
pub fn new() -> InvitePermissionConfigEventContent
pub fn new() -> InvitePermissionConfigEventContent
Creates a new empty InvitePermissionConfigEventContent.